@@ -89,8 +89,8 @@ void gSummaryChart::SetDay(Day *unused_day)
         date = date.addDays(1);
     } while (date <= lastday);
 
-    m_minx = QDateTime(firstday, QTime(0,0,0), Qt::UTC).toMSecsSinceEpoch();
-    m_maxx = QDateTime(lastday, QTime(23,59,59), Qt::UTC).toMSecsSinceEpoch();
+    m_minx = QDateTime(firstday, QTime(0,0,0), Qt::LocalTime).toMSecsSinceEpoch();
+    m_maxx = QDateTime(lastday, QTime(23,59,59), Qt::LocalTime).toMSecsSinceEpoch();
     m_miny = 0;
     m_maxy = 20;
 
@@ -148,7 +148,7 @@ bool gSummaryChart::mouseReleaseEvent(QMouseEvent *event, gGraph *graph)
 
     graph->roundY(miny, maxy);
 
-    QDate date = QDateTime::fromMSecsSinceEpoch(m_minx, Qt::UTC).date();
+    QDate date = QDateTime::fromMSecsSinceEpoch(m_minx, Qt::LocalTime).date();
 
     int days = ceil(double(m_maxx - m_minx) / 86400000.0);
 
@@ -317,9 +317,10 @@ QString gSummaryChart::tooltipData(Day *, int idx)
 {
     QString txt;
     const auto & slices = cache[idx];
-    for (const auto & slice : slices) {
-        txt += QString("\n%1: %2").arg(slice.name).arg(float(slice.value), 0, 'f', 2);
-
+    int i = slices.size();
+    while (i > 0) {
+        i--;
+        txt += QString("\n%1: %2").arg(slices[i].name).arg(float(slices[i].value), 0, 'f', 2);
     }
     return txt;
 }
@@ -414,8 +415,8 @@ void gSummaryChart::paint(QPainter &painter, gGraph &graph, const QRegion &regio
     m_minx = graph.min_x;
     m_maxx = graph.max_x;
 
-    QDateTime date2 = QDateTime::fromMSecsSinceEpoch(m_minx, Qt::UTC);
-    QDateTime enddate2 = QDateTime::fromMSecsSinceEpoch(m_maxx, Qt::UTC);
+    QDateTime date2 = QDateTime::fromMSecsSinceEpoch(m_minx, Qt::LocalTime);
+    QDateTime enddate2 = QDateTime::fromMSecsSinceEpoch(m_maxx, Qt::LocalTime);
 
     QDate date = date2.date();
     QDate enddate = enddate2.date();
@@ -838,8 +839,8 @@ void gSessionTimesChart::paint(QPainter &painter, gGraph &graph, const QRegion &
     m_minx = graph.min_x;
     m_maxx = graph.max_x;
 
-    QDateTime date2 = QDateTime::fromMSecsSinceEpoch(m_minx, Qt::UTC);
-    QDateTime enddate2 = QDateTime::fromMSecsSinceEpoch(m_maxx, Qt::UTC);
+    QDateTime date2 = QDateTime::fromMSecsSinceEpoch(m_minx, Qt::LocalTime);
+    QDateTime enddate2 = QDateTime::fromMSecsSinceEpoch(m_maxx, Qt::LocalTime);
 
     QDate date = date2.date();
     QDate enddate = enddate2.date();
@@ -1240,33 +1241,35 @@ void gAHIChart::afterDraw(QPainter & /*painter */, gGraph &graph, QRectF rect)
     QStringList txtlist;
     if (!skip) txtlist.append(QObject::tr("%1 %2 / %3 / %4").arg(STR_TR_AHI).arg(min_ahi, 0, 'f', 2).arg(med, 0, 'f', 2).arg(max_ahi, 0, 'f', 2));
 
-    for (auto & calc : calcitems) {
-        ChannelID code = calc.code;
+    int i = calcitems.size();
+    while (i > 0) {
+        i--;
+        ChannelID code = calcitems[i].code;
         schema::Channel & chan = schema::channel[code];
         float mid = 0;
         skip = true;
         switch (midcalc) {
         case 0:
-            if (calc.median_data.size() > 0) {
-                mid = median(calc.median_data.begin(), calc.median_data.end());
+            if (calcitems[i].median_data.size() > 0) {
+                mid = median(calcitems[i].median_data.begin(), calcitems[i].median_data.end());
                 skip = false;
             }
             break;
         case 1:
-            if (calc.divisor > 0) {
-                mid = calc.wavg_sum / calc.divisor;
+            if (calcitems[i].divisor > 0) {
+                mid = calcitems[i].wavg_sum / calcitems[i].divisor;
                 skip = false;
             }
             break;
         case 2:
-            if (calc.cnt > 0) {
-                mid = calc.avg_sum / calc.cnt;
+            if (calcitems[i].cnt > 0) {
+                mid = calcitems[i].avg_sum / calcitems[i].cnt;
                 skip = false;
             }
             break;
         }
 
-        if (!skip) txtlist.append(QString("%1 %2 / %3 / %4").arg(chan.label()).arg(calc.min, 0, 'f', 2).arg(mid, 0, 'f', 2).arg(calc.max, 0, 'f', 2));
+        if (!skip) txtlist.append(QString("%1 %2 / %3 / %4").arg(chan.label()).arg(calcitems[i].min, 0, 'f', 2).arg(mid, 0, 'f', 2).arg(calcitems[i].max, 0, 'f', 2));
     }
     QString txt = txtlist.join(", ");
     graph.renderText(txt, rect.left(), rect.top()-5*graph.printScaleY(), 0);
@@ -1294,9 +1297,11 @@ QString gAHIChart::tooltipData(Day *day, int idx)
     float total = 0;
     float hour = day->hours(m_machtype);
     QString txt;
-    for (const auto & slice : slices) {
-        total += slice.value;
-        txt += QString("\n%1: %2").arg(slice.name).arg(float(slice.value) / hour, 0, 'f', 2);
+    int i = slices.size();
+    while (i > 0) {
+        i--;
+        total += slices[i].value;
+        txt += QString("\n%1: %2").arg(slices[i].name).arg(float(slices[i].value) / hour, 0, 'f', 2);
     }
     return QString("\n%1: %2").arg(STR_TR_AHI).arg(float(total) / hour,0,'f',2)+txt;
 }
