@@ -142,7 +142,8 @@ bool Machine::saveSessionInfo()
     QString filename = getDataPath() + "Sessions.info";
     QFile file(filename);
     if (!file.open(QFile::WriteOnly)) {
-        qDebug() << "Couldn't open" << filename << "for writing";
+//        qDebug() << "Couldn't open" << filename << "for writing";
+        qWarning() << "Couldn't open" << filename << "for writing, error code" << file.error() << file.errorString();
         return false;
     }
 
@@ -186,7 +187,7 @@ bool Machine::loadSessionInfo()
     QHash<SessionID, Session *>::iterator s;
     QFile file(getDataPath() + "Sessions.info");
 
-    if (!file.open(QFile::ReadOnly)) {
+    if ( ! file.open(QFile::ReadOnly)) {
         // No session.info file present, so let's create one...
 
         // But first check for legacy SESSION_ENABLED field in session settings
@@ -391,7 +392,7 @@ bool Machine::AddSession(Session *s)
         return true;
     }
 
-    if (!firstsession) {
+    if ( ! firstsession) {
         if (firstday > date) { firstday = date; }
 
         if (lastday < date) { lastday = date; }
@@ -610,7 +611,9 @@ void Machine::setLoaderName(QString value)
 
 void Machine::setInfo(MachineInfo inf)
 {
-    info = inf;
+    MachineInfo merged = inf;
+    if (info.purgeDate.isValid()) merged.purgeDate = info.purgeDate;
+    info = merged;
     m_loader = GetLoader(inf.loadername);
 }
 
@@ -677,8 +680,11 @@ bool Machine::Load(ProgressDialog *progress)
         return false;
     }
 
-    QPixmap image = getPixmap().scaled(64,64);
-    progress->setPixmap(image);
+    QPixmap image = getPixmap();
+    if (!image.isNull()) {
+        image = image.scaled(64,64);
+        progress->setPixmap(image);
+    }
     progress->setMessage(QObject::tr("Loading %1 data for %2...").arg(info.brand).arg(profile->user->userName()));
 
     if (loader()) {
@@ -687,7 +693,8 @@ bool Machine::Load(ProgressDialog *progress)
         mainwin->connect(loader(), SIGNAL(setProgressValue(int)), progress, SLOT(setProgressValue(int)));
     }
 
-    if (!LoadSummary(progress)) {
+    if ( ! LoadSummary(progress)) {
+        qDebug() << "Recreating the Summary index XML file";
         // No XML index file, so assume upgrading, or it simply just got screwed up or deleted...
         progress->setMessage(QObject::tr("Scanning Files"));
         progress->setProgressValue(0);
@@ -751,6 +758,7 @@ bool Machine::Load(ProgressDialog *progress)
         size = filelist.size();
 
         progress->setMessage("Reading summary files");
+        qDebug() << "Reading summary files (.000)";
         progress->setProgressValue(0);
         QApplication::processEvents();
 
@@ -787,6 +795,7 @@ bool Machine::Load(ProgressDialog *progress)
         progress->setProgressValue(size);
     }
     progress->setMessage("Loading Session Info");
+    qDebug() << "Loading Session Info";
     QApplication::processEvents();
 
     loadSessionInfo();
@@ -804,7 +813,9 @@ bool Machine::SaveSession(Session *sess)
 {
     QString path = getDataPath();
 
-    if (sess->IsChanged() && sess->first() != 0) { sess->Store(path); }
+    if (sess->IsChanged() && sess->first() != 0) {
+        sess->Store(path);
+    }
 
     return true;
 }
@@ -838,8 +849,11 @@ void Machine::queTask(ImportTask * task)
 
 void Machine::runTasks()
 {
-    if (m_tasklist.isEmpty())
+    if (m_tasklist.isEmpty()) {
+        qDebug() << "No tasks in m_tasklist";
         return;
+    }
+    qDebug() << "m_tasklist size is" << m_tasklist.size();
 
     QThreadPool * threadpool = QThreadPool::globalInstance();
 /***********************************************************
@@ -848,7 +862,7 @@ void Machine::runTasks()
 //  if (loader())
 //      emit loader()->setProgressMax(m_totaltasks);
 ***********************************************************/
-    while (!m_tasklist.isEmpty()) {
+    while ( ! m_tasklist.isEmpty()) {
         if (threadpool->tryStart(m_tasklist.at(0))) {
             m_tasklist.pop_front();
 /************************************************************
@@ -890,7 +904,8 @@ bool Machine::LoadSummary(ProgressDialog * progress)
     QApplication::processEvents();
 
     if (!file.open(QIODevice::ReadOnly)) {
-        qWarning() << "Could not open" << filename;
+//        qWarning() << "Could not open" << filename;
+        qWarning() << "Could not open" << filename << "for reading, error code" << file.error() << file.errorString();
         return false;
     }
 
@@ -1004,7 +1019,7 @@ bool Machine::LoadSummary(ProgressDialog * progress)
 //      } 
 *****************************************************************/
         Session * sess = it.value();
-        if (!AddSession(sess)) {
+        if ( ! AddSession(sess)) {
             delete sess;
         } else {
             if (loadSummaries) {
@@ -1018,6 +1033,7 @@ bool Machine::LoadSummary(ProgressDialog * progress)
         }
     }
     progress->setMessage(QObject::tr("Loading Summary Data"));
+    qDebug() << "Loading Summary Data";
     QApplication::processEvents();
 
     if (loader()) {
@@ -1104,7 +1120,9 @@ bool Machine::SaveSummaryCache()
 
     QFile file(filename + ".gz");
 
-    file.open(QFile::WriteOnly);
+    if (!file.open(QFile::WriteOnly)) {
+        qWarning() << "Couldn't open summary cache" << filename << "for writing, error code" << file.error() << file.errorString();
+    }
     file.write(data);
 
     return true;
