@@ -140,6 +140,7 @@ QString Profile::checkLock()
     return lockhost;
 }
 
+// Properties for machines.xml:
 const QString STR_PROP_Brand = "brand";
 const QString STR_PROP_Model = "model";
 const QString STR_PROP_Series = "series";
@@ -148,6 +149,7 @@ const QString STR_PROP_SubModel = "submodel";
 const QString STR_PROP_Serial = "serial";
 const QString STR_PROP_DataVersion = "dataversion";
 const QString STR_PROP_LastImported = "lastimported";
+const QString STR_PROP_PurgeDate = "purgedate";
 
 void Profile::addLock()
 {
@@ -169,9 +171,11 @@ bool Profile::OpenMachines()
     QString filename = p_path+"machines.xml";
     QFile file(filename);
     if (!file.open(QFile::ReadOnly)) {
-        qWarning() << "Could not open" << filename.toLocal8Bit().data();
+        qWarning() << "Could not open" << filename.toLocal8Bit().data() << "for reading, error code" << file.error() << file.errorString();
         return false;
     }
+//    qDebug() << "OpenMachines opened" << filename.toLocal8Bit().data();
+
     QDomDocument doc("machines.xml");
 
     if (!doc.setContent(&file)) {
@@ -182,7 +186,7 @@ bool Profile::OpenMachines()
     QDomElement root = doc.firstChild().toElement();
 
     if (root.tagName().toLower() != "machines") {
-        qDebug() << "No Machines Tag in machines.xml";
+        qWarning() << "No Machines Tag in machines.xml";
         return false;
     }
 
@@ -232,6 +236,8 @@ bool Profile::OpenMachines()
                 info.version = e.text().toInt();
             } else if (key == STR_PROP_LastImported) {
                 info.lastimported = QDateTime::fromString(e.text(), Qt::ISODate);
+            } else if (key == STR_PROP_PurgeDate) {
+                info.purgeDate = QDate::fromString(e.text(), Qt::ISODate);
             } else if (key == "properties") {
                 QDomElement pe = e.firstChildElement();
                 for (; !pe.isNull(); pe = pe.nextSiblingElement()) {
@@ -310,6 +316,10 @@ bool Profile::StoreMachines()
         mp.appendChild(doc.createTextNode(m->lastImported().toString(Qt::ISODate)));
         me.appendChild(mp);
 
+        mp = doc.createElement(STR_PROP_PurgeDate);
+        mp.appendChild(doc.createTextNode(m->purgeDate().toString(Qt::ISODate)));
+        me.appendChild(mp);
+
         mach.appendChild(me);
     }
 
@@ -318,8 +328,10 @@ bool Profile::StoreMachines()
     QString filename = p_path+"machines.xml";
     QFile file(filename);
     if (!file.open(QFile::WriteOnly)) {
+        qWarning() << "Could not open" << filename << "for writing, error code" << file.error() << file.errorString();
         return false;
     }
+
     file.write(doc.toByteArray());
     return true;
 }
@@ -630,7 +642,7 @@ void Profile::LoadMachineData(ProgressDialog *progress)
 
         if (loader) {
             if (mach->version() < loader->Version()) {
-                qDebug() << "LoadMachineData data format error, machine version" << mach->version() << "loader version" << loader->Version();
+                qDebug() << "LoadMachineData" << mach->loaderName() << "data format error, machine version" << mach->version() << "loader version" << loader->Version();
                 progress->hide();
                 DataFormatError(mach);
                 progress->show();
@@ -638,7 +650,7 @@ void Profile::LoadMachineData(ProgressDialog *progress)
                 try {
                     mach->Load(progress);
                 } catch (OldDBVersion& e) {
-                    qDebug() << "LoadMachineData mach->load failure, machine version" << mach->version() << "loader version" << loader->Version();
+                    qDebug() << "LoadMachineData" << mach->loaderName() << "load failure, machine version" << mach->version() << "loader version" << loader->Version();
                     Q_UNUSED(e)
                     progress->hide();
                     DataFormatError(mach);
@@ -929,7 +941,14 @@ Machine *Profile::GetMachine(MachineType t)
         return nullptr;
     }
 
-    return vec[0];
+    // Find most recently imported machine
+    int idx = 0;
+
+    for (int i=1; i < vec.size(); i++) {
+        if (vec[i]->lastImported() > vec[idx]->lastImported())
+            idx = i;
+    }
+    return vec[idx];
 }
 
 //bool Profile::trashMachine(Machine * mach)
@@ -1068,7 +1087,10 @@ void saveProfileList()
     }
 
     QFile file(filename);
-    file.open(QFile::WriteOnly);
+    if (!file.open(QFile::WriteOnly)) {
+        qWarning() << "Could not open" << filename << "for writing, error code" << file.error() << file.errorString();
+        return;
+    }
 
     file.write(doc.toByteArray());
 
@@ -1132,6 +1154,9 @@ void Scan()
     // Iterate through subdirectories and load profiles..
     for (auto & fi : list) {
         QString npath = fi.canonicalFilePath();
+        QDir profilePath(npath);
+        if (profilePath.isEmpty())  // skip any empty folders
+            continue;
         Profile *prof = new Profile(npath);
         //prof->Open();
 
@@ -1342,7 +1367,7 @@ EventDataType Profile::calcHours(MachineType mt, QDate start, QDate end)
         Day *day = GetGoodDay(date, mt);
 
         if (day) {
-            val += day->hours();
+            val += day->hours(mt);
         }
 
         date = date.addDays(1);
@@ -1709,69 +1734,70 @@ EventDataType Profile::calcPercentile(ChannelID code, EventDataType percent, Mac
 
     qint64 SN = 0;
     bool timeweight;
-    bool summaryOnly = false;
-
+    bool summaryOnly = true;
     do {
         Day *day = GetGoodDay(date, mt);
 
         if (day) {
             if (day->summaryOnly()) {
-                summaryOnly = true;
-                break;
+                date = date.addDays(1);
+                continue;
             }
 
+            summaryOnly = false;
+
             // why was this nested like this???
             //for (int i = 0; i < day->size(); i++) {
-                for (auto & sess : day->sessions) {
-                    if (!sess->enabled()) {
-                        continue;
-                    }
+            for (auto & sess : day->sessions) {
+                if (!sess->enabled()) {
+                    continue;
+                }
 
-                    gain = sess->m_gain[code];
+                gain = sess->m_gain[code];
 
-                    if (!gain) { gain = 1; }
+                if (!gain) { gain = 1; }
 
-                    vsi = sess->m_valuesummary.find(code);
+                vsi = sess->m_valuesummary.find(code);
 
-                    if (vsi == sess->m_valuesummary.end()) { continue; }
+                if (vsi == sess->m_valuesummary.end()) { continue; }
 
-                    tsi = sess->m_timesummary.find(code);
-                    timeweight = (tsi != sess->m_timesummary.end());
+                tsi = sess->m_timesummary.find(code);
+                timeweight = (tsi != sess->m_timesummary.end());
 
-                    QHash<EventStoreType, EventStoreType> &vsum = vsi.value();
-                    QHash<EventStoreType, quint32> &tsum = tsi.value();
+                QHash<EventStoreType, EventStoreType> &vsum = vsi.value();
+                QHash<EventStoreType, quint32> &tsum = tsi.value();
 
-                    if (timeweight) {
-                        for (auto k=tsum.begin(), tsumend=tsum.end(); k != tsumend; k++) {
-                            weight = k.value();
-                            value = EventDataType(k.key()) * gain;
+                if (timeweight) {
+                    for (auto k=tsum.begin(), tsumend=tsum.end(); k != tsumend; k++) {
+                        weight = k.value();
+                        value = EventDataType(k.key()) * gain;
 
-                            SN += weight;
-                            wmi = wmap.find(value);
+                        SN += weight;
+                        wmi = wmap.find(value);
 
-                            if (wmi == wmap.end()) {
-                                wmap[value] = weight;
-                            } else {
-                                wmi.value() += weight;
-                            }
+                        if (wmi == wmap.end()) {
+                            wmap[value] = weight;
+                        } else {
+                            wmi.value() += weight;
                         }
-                    } else {
-                        for (auto k=vsum.begin(), vsumend=vsum.end(); k!=vsumend; k++) {
-                            weight = k.value();
-                            value = EventDataType(k.key()) * gain;
+                    }
+                } else {
+                    for (auto k=vsum.begin(), vsumend=vsum.end(); k!=vsumend; k++) {
+                        weight = k.value();
+                        value = EventDataType(k.key()) * gain;
 
-                            SN += weight;
-                            wmi = wmap.find(value);
+                        SN += weight;
+                        wmi = wmap.find(value);
 
-                            if (wmi == wmap.end()) {
-                                wmap[value] = weight;
-                            } else {
-                                wmi.value() += weight;
-                            }
+                        if (wmi == wmap.end()) {
+                            wmap[value] = weight;
+                        } else {
+                            wmi.value() += weight;
                         }
                     }
                 }
-           // }
+            }
+            // }
         }
 
         date = date.addDays(1);
@@ -1868,7 +1894,7 @@ QDate Profile::FirstDay(MachineType mt)
     return m_last;
 }
 
-// Lookup last day record of the specified machine type, or return the first day overall if MT_UNKNOWN
+// Lookup last day record of the specified machine type, or return the last day overall if MT_UNKNOWN
 QDate Profile::LastDay(MachineType mt)
 {
     if ((mt == MT_UNKNOWN) || (!m_last.isValid()) || (!m_first.isValid())) {
