@@ -108,7 +108,7 @@ void init()
     // Note: Old channel names stored in channels.xml are not translatable.. they need to be moved to be defined AFTER here instead
     if (!schema::channel.Load(":/docs/channels.xml")) {
         QMessageBox::critical(0, STR_MessageBox_Error,
-                              QObject::tr("Couldn't parse Channels.xml, this build is seriously borked, no choice but to abort!!"),
+                              QObject::tr("Couldn't parse Channels.xml, OSCAR cannot continue and is exiting."),
                               QMessageBox::Ok);
         QApplication::exit(-1);
     }
@@ -340,8 +340,8 @@ void init()
 //  <channel id="0x111e" class="data" name="TestChan1" details="Debugging Channel #1" label="Test #1" unit="" color="pink"/>
 //  <channel id="0x111f" class="data" name="TestChan2" details="Debugging Channel #2" label="Test #2" unit="" color="blue"/>
 
-    schema::channel.add(GRP_CPAP, ch=new Channel(CPAP_Test1 = 0x111e, DATA, MT_CPAP, SESSION, STR_GRAPH_TestChan1, QObject::tr("Debugging channel #1"), QObject::tr("Top secret internal stuff you're not supposed to see ;)"), QObject::tr("Test #1"),  QString(), INTEGER,  QColor("pink")));
-    schema::channel.add(GRP_CPAP, ch=new Channel(CPAP_Test2 = 0x111f, DATA, MT_CPAP, SESSION, STR_GRAPH_TestChan2, QObject::tr("Debugging channel #2"), QObject::tr("Top secret internal stuff you're not supposed to see ;)"), QObject::tr("Test #2"),  QString(), INTEGER,  Qt::blue));
+    schema::channel.add(GRP_CPAP, ch=new Channel(CPAP_Test1 = 0x111e, DATA, MT_CPAP, SESSION, STR_GRAPH_TestChan1, QObject::tr("Debugging channel #1"), QObject::tr("For internal use only"), QObject::tr("Test #1"),  QString(), INTEGER,  QColor("pink")));
+    schema::channel.add(GRP_CPAP, ch=new Channel(CPAP_Test2 = 0x111f, DATA, MT_CPAP, SESSION, STR_GRAPH_TestChan2, QObject::tr("Debugging channel #2"), QObject::tr("For internal use only"), QObject::tr("Test #2"),  QString(), INTEGER,  Qt::blue));
 
     RMS9_E01 = schema::channel["RMS9_E01"].id();
     RMS9_E02 = schema::channel["RMS9_E02"].id();
@@ -446,7 +446,8 @@ bool ChannelList::Load(QString filename)
     qDebug() << "Opening " << filename;
 
     if (!file.open(QIODevice::ReadOnly)) {
-        qWarning() << "Could not open" << filename;
+//        qWarning() << "Could not open" << filename;
+        qWarning() << "Could not open" << filename << "for reading, error code" << file.error() << file.errorString();
         return false;
     }
 
@@ -715,6 +716,7 @@ bool ChannelList::Save(QString filename)
     QFile file(filename);
 
     if (!file.open(QIODevice::WriteOnly)) {
+        qWarning() << "Could not open" << filename << "for writing, error code" << file.error() << file.errorString();
         return false;
     }
 
