@@ -1086,16 +1086,18 @@ QString Daily::getMachineSettings(Day * day) {
     if (cpap && day->hasEnabledSessions(MT_CPAP)) {
         html="<table cellpadding=0 cellspacing=0 border=0 width=100%>";
         html+=QString("<tr><td colspan=5 align=center><b>%1</b></td></tr>").arg(tr("Machine Settings"));
-        html+="<tr><td colspan=5>&nbsp;</td></tr>";
 
         if (day->noSettings(cpap)) {
-            html+="<tr><td colspan=5 align=center><i>"+tr("<b>Please Note:</b> All settings shown below are based on assumptions that nothing has changed since previous days.")+"</i></td></tr>\n";
+            html+="<tr><td colspan=5 align=center><i><font color='red'>"+tr("<b>Please Note:</b> All settings shown below are based on assumptions that nothing has changed since previous days.")+"</font></i></td></tr>\n";
+        } else {
+            html+="<tr><td colspan=5>&nbsp;</td></tr>";
+        }
         /*
         } else if ((day->settingExists(CPAP_BrokenSummary))) {
             html+="<tr><td colspan=5 align=center><i>"+tr("Machine Settings Unavailable")+"</i></td></tr></table><hr/>\n";
             return html;
-        */
         }
+        */
 
         QMap<QString, QString> other;
         Session * sess = day->firstSession(MT_CPAP);
@@ -1245,7 +1247,7 @@ QString Daily::getCPAPInformation(Day * day)
     html+= day->getPressureSettings();
     html+="</td></tr>\n";
     if (day->noSettings(cpap)) {
-        html+=QString("<tr><td colspan=2 align=center><i>%1</i></td></tr>").arg(tr("(Mode/Pressure settings are guessed on this day.)"));
+        html+=QString("<tr><td align=center><font color='red'><i>%1</i></font></td></tr>").arg(tr("(Mode and Pressure settings missing; yesterday's shown.)"));
     }
 
     html+="</table>\n";
@@ -1343,6 +1345,10 @@ QString Daily::getStatisticsInfo(Day * day)
             }
         }
 
+//        QString oldtip = tooltip;
+        tooltip.replace("'", "&apos;");
+//        qDebug() << schema::channel[code].label() << "old tooltip" << oldtip << "tooltip" << tooltip ;
+
         html+=QString("<tr><td align=left title='%6'>%1</td><td>%2</td><td>%3</td><td>%4</td><td>%5</td></tr>")
             .arg(schema::channel[code].label())
             .arg(mn,0,'f',2)
@@ -1356,7 +1362,7 @@ QString Daily::getStatisticsInfo(Day * day)
 
     if (GraphView->isEmpty() && ((ccnt>0) || (cpap && day->summaryOnly()))) {
         html+="<tr><td colspan=5>&nbsp;</td></tr>\n";
-        html+=QString("<tr><td colspan=5 align=center><i>%1</i></td></tr>").arg("<b>"+STR_MessageBox_PleaseNote+"</b> "+ 
+        html+=QString("<tr><td colspan=5 align=center><i>%1</i></td></tr>").arg("<b>"+STR_MessageBox_PleaseNote+"</b> "+
                     tr("This day just contains summary data, only limited information is available."));
     } else if (cpap) {
         html+="<tr><td colspan=5>&nbsp;</td></tr>";
@@ -1429,7 +1435,7 @@ QString Daily::getSleepTime(Day * day)
 
     html+="<table cellspacing=0 cellpadding=0 border=0 width='100%'>\n";
     html+="<tr><td align='center'><b>"+STR_TR_Date+"</b></td><td align='center'><b>"+tr("Start")+"</b></td><td align='center'><b>"+tr("End")+"</b></td><td align='center'><b>"+STR_UNIT_Hours+"</b></td></tr>";
-    int tt=qint64(day->total_time())/1000L;
+    int tt=qint64(day->total_time(MT_CPAP))/1000L;
     QDateTime date=QDateTime::fromTime_t(day->first()/1000L);
     QDateTime date2=QDateTime::fromTime_t(day->last()/1000L);
 
