@@ -28,6 +28,7 @@
 #include "SleepLib/profiles.h"
 #include "translation.h"
 #include "SleepLib/common.h"
+#include "SleepLib/deviceconnection.h"
 
 #include <ctime>
 #include <chrono>
@@ -88,8 +89,10 @@ bool copyRecursively(QString sourceFolder, QString destFolder, QProgressDialog&
             progress.setValue(numFilesCopied);
             QCoreApplication::processEvents();
         }
-        if(!success)
+        if(!success) {
+            qWarning() << "copyRecursively: Unable to copy" << srcName << "to" << destName;
             return false;
+        }
     }
 
     files.clear();
@@ -117,9 +120,12 @@ bool processPreferenceFile( QString path ) {
     tmp.open(QIODevice::WriteOnly);
     QTextStream instr(&fl);
     QTextStream outstr(&tmp);
+    bool isSleepyHead = false;
     while (instr.readLineInto(&line)) {
+        if (line.contains("<SleepyHead>"))  // Is this SleepyHead or OSCAR preferences file?
+            isSleepyHead = true;
         line.replace("SleepyHead","OSCAR");
-        if (line.contains("VersionString")) {
+        if (isSleepyHead && line.contains("VersionString")) {
             int rtAngle = line.indexOf(">", 0);
             int lfAngle = line.indexOf("<", rtAngle);
             line.replace(rtAngle+1, lfAngle-rtAngle-1, "1.0.0-beta");
@@ -182,7 +188,7 @@ bool migrateFromSH(QString destDir) {
 
     while (selectingFolder) {
         datadir = QFileDialog::getExistingDirectory(nullptr,
-                  QObject::tr("Choose the SleepyHead data folder to migrate")+" "+
+                  QObject::tr("Choose the SleepyHead or OSCAR data folder to migrate")+" "+
                   QObject::tr("or CANCEL to skip migration."),
                   homeDocs, QFileDialog::ShowDirsOnly);
         qDebug() << "Migration folder selected: " + datadir;
@@ -197,7 +203,7 @@ bool migrateFromSH(QString destDir) {
             if (!file.exists() || !dirP.exists()) {       // It doesn't have a Preferences.xml file or a Profiles directory in it
                 // Not a new directory.. nag the user.
                 QMessageBox::warning(nullptr, STR_MessageBox_Error,
-                                     QObject::tr("The folder you chose does not contain valid SleepyHead data.") +
+                                     QObject::tr("The folder you chose does not contain valid SleepyHead or OSCAR data.") +
                                      "\n\n"+QObject::tr("You cannot use this folder:")+" " + datadir,
                                      QMessageBox::Ok);
                 continue;   // Nope, don't use it, go around the loop again
@@ -376,7 +382,7 @@ int main(int argc, char *argv[]) {
     initializeLogger();
     // After initializing the logger, any qDebug() messages will be queued but not written to console
     // until MainWindow is constructed below. In spite of that, we initialize the logger here so that
-    // the intervening messages to show up in the debug pane.
+    // the intervening messages show up in the debug pane.
     //
     // The only time this is really noticeable is when initTranslations() presents its language
     // selection QDialog, which waits indefinitely for user input before MainWindow is constructed.
@@ -483,7 +489,8 @@ int main(int argc, char *argv[]) {
         if ( ! force_data_dir ) {       // unless they explicitly selected it by --datadir param
             if (QMessageBox::question(nullptr, STR_MessageBox_Question,
                                       QObject::tr("OSCAR will set up a folder for your data.")+"\n"+
-                                      QObject::tr("If you have been using SleepyHead, OSCAR can copy your old data to this folder later.")+"\n"+
+                                      QObject::tr("If you have been using SleepyHead or an older version of OSCAR,") + "\n" +
+                                      QObject::tr("OSCAR can copy your old data to this folder later.")+"\n"+
                                       QObject::tr("We suggest you use this folder: ")+QDir::toNativeSeparators(GetAppData())+"\n"+
                                       QObject::tr("Click Ok to accept this, or No if you want to use a different folder."),
                                       QMessageBox::Ok | QMessageBox::No, QMessageBox::Ok) == QMessageBox::No) {
@@ -532,18 +539,47 @@ int main(int argc, char *argv[]) {
 
     QDir newDir(GetAppData());
 #if QT_VERSION < QT_VERSION_CHECK(5,9,0)
-    if ( ! newDir.exists() || newDir.count() == 0 ) {     // directoy doesn't exist yet or is empty, try to migrate old data
+    if ( ! newDir.exists() || newDir.count() == 0 ) {     // directory doesn't exist yet or is empty, try to migrate old data
 #else
-    if ( ! newDir.exists() || newDir.isEmpty() ) {        // directoy doesn't exist yet or is empty, try to migrate old data
+    if ( ! newDir.exists() || newDir.isEmpty() ) {        // directory doesn't exist yet or is empty, try to migrate old data
 #endif
-        if (QMessageBox::question(nullptr, QObject::tr("Migrate SleepyHead Data?"),
-                                  QObject::tr("On the next screen OSCAR will ask you to select a folder with SleepyHead data") +"\n" +
-                                  QObject::tr("Click [OK] to go to the next screen or [No] if you do not wish to use any SleepyHead data."),
+        if (QMessageBox::question(nullptr, QObject::tr("Migrate SleepyHead or OSCAR Data?"),
+                                  QObject::tr("On the next screen OSCAR will ask you to select a folder with SleepyHead or OSCAR data") +"\n" +
+                                  QObject::tr("Click [OK] to go to the next screen or [No] if you do not wish to use any SleepyHead or OSCAR data."),
                                   QMessageBox::Ok|QMessageBox::No, QMessageBox::Ok) == QMessageBox::Ok) {
             migrateFromSH( GetAppData() );              // doesn't matter if no migration
         }
     }
 
+    // Make sure the data directory exists.
+    if (!newDir.mkpath(".")) {
+        QMessageBox::warning(nullptr, QObject::tr("Exiting"),
+                             QObject::tr("Unable to create the OSCAR data folder at")+"\n"+
+                             GetAppData());
+        return 0;
+    }
+
+    // Make sure we can write to the data directory
+    QFile testFile(GetAppData()+"/testfile.txt");
+    if (testFile.exists())
+        testFile.remove();
+    if (!testFile.open(QFile::ReadWrite)) {
+        QString errMsg = QObject::tr("Unable to write to OSCAR data directory") + " " + GetAppData() + "\n" +
+                         GetAppData() + "\n" +
+                         QObject::tr("Error code") + ": " + QString::number(testFile.error()) + " - " + testFile.errorString() + "\n\n" +
+                         QObject::tr("OSCAR cannot continue and is exiting.") + "\n";
+        qCritical() << errMsg;
+        QMessageBox::critical(nullptr, QObject::tr("Exiting"), errMsg);
+        return 0;
+    }
+    else
+        testFile.remove();
+
+    // Begin logging to file now that there's a data folder.
+    if (!logger->logToFile()) {
+        QMessageBox::warning(nullptr, STR_MessageBox_Warning,
+                             QObject::tr("Unable to write to debug log. You can still use the debug pane (Help/Troubleshooting/Show Debug Pane) but the debug log will not be written to disk."));
+    }
 
     ///////////////////////////////////////////////////////////////////////////////////////////
     // Initialize preferences system (Don't use p_pref before this point!)
@@ -565,7 +601,7 @@ int main(int argc, char *argv[]) {
     p_pref->Erase(STR_AppName);
     p_pref->Erase(STR_GEN_SkipLogin);
 
-#ifndef NO_UPDATER
+#ifndef NO_CHECKUPDATES
     ////////////////////////////////////////////////////////////////////////////////////////////
     // Check when last checked for updates..
     ////////////////////////////////////////////////////////////////////////////////////////////
@@ -573,6 +609,13 @@ int main(int argc, char *argv[]) {
 
     bool check_updates = false;
 
+    if (!getVersion().IsReleaseVersion()) {
+        // If test build, force update autocheck, no more than 7 day interval, show test versions
+        AppSetting->setUpdatesAutoCheck(true);
+        AppSetting->setUpdateCheckFrequency(min(AppSetting->updateCheckFrequency(), 7));
+        AppSetting->setAllowEarlyUpdates(true);
+    }
+
     if (AppSetting->updatesAutoCheck()) {
         int update_frequency = AppSetting->updateCheckFrequency();
         int days = 1000;
@@ -583,7 +626,7 @@ int main(int argc, char *argv[]) {
             days /= 86400;
         }
 
-        if (days > update_frequency) {
+        if (days >= update_frequency) {
             check_updates = true;
         }
     }
@@ -629,6 +672,21 @@ int main(int argc, char *argv[]) {
     MD300W1Loader::Register();
     ViatomLoader::Register();
 
+    // Begin logging device connection activity.
+    QString connectionsLogDir = GetLogDir() + "/connections";
+    rotateLogs(connectionsLogDir);  // keep a limited set of previous logs
+    if (!QDir(connectionsLogDir).mkpath(".")) {
+        qWarning().noquote() << "Unable to create directory" << connectionsLogDir;
+    }
+
+    QFile deviceLog(connectionsLogDir + "/devices.xml");
+    if (deviceLog.open(QFile::ReadWrite)) {
+        qDebug().noquote() << "Logging device connections to" << deviceLog.fileName();
+        DeviceConnectionManager::getInstance().record(&deviceLog);
+    } else {
+        qWarning().noquote() << "Unable to start device connection logging to" << deviceLog.fileName();
+    }
+
     schema::setOrders(); // could be called in init...
 
     // Scan for user profiles
@@ -637,16 +695,20 @@ int main(int argc, char *argv[]) {
     Q_UNUSED(changing_language)
     Q_UNUSED(dont_load_profile)
 
-#ifndef NO_UPDATER
+#ifndef NO_CHECKUPDATES
     if (check_updates) {
-        mainwin->CheckForUpdates();
+        mainwin->CheckForUpdates(false);
     }
 #endif
 
     mainwin->SetupGUI();
     mainwin->show();
 
-    return a.exec();
+    int result = a.exec();
+    
+    DeviceConnectionManager::getInstance().record(nullptr);
+    
+    return result;
 }
 
 #endif // !UNITTEST_MODE
