@@ -31,6 +31,7 @@
 #include <QStandardPaths>
 #include <QDesktopServices>
 #include <QScreen>
+#include <QStorageInfo>
 #include <cmath>
 
 #include "common_gui.h"
@@ -55,7 +56,7 @@
 #include "exportcsv.h"
 #include "SleepLib/schema.h"
 #include "Graphs/glcommon.h"
-#include "UpdaterWindow.h"
+#include "checkupdates.h"
 #include "SleepLib/calcs.h"
 #include "SleepLib/progressdialog.h"
 
@@ -67,6 +68,8 @@
 #include <QOpenGLFunctions>
 #endif
 
+CheckUpdates *updateChecker;
+
 MainWindow::MainWindow(QWidget *parent) :
     QMainWindow(parent),
     ui(new Ui::MainWindow)
@@ -148,6 +151,9 @@ void MainWindow::SetupGUI()
     profileSelector = nullptr;
     welcome = nullptr;
 
+#ifdef NO_CHECKUPDATES
+    ui->action_Check_for_Updates->setVisible(false);
+#endif
     ui->oximetryButton->setDisabled(true);
     ui->dailyButton->setDisabled(true);
     ui->overviewButton->setDisabled(true);
@@ -212,7 +218,7 @@ void MainWindow::SetupGUI()
     first_load = true;
 
     profileSelector = new ProfileSelector(ui->tabWidget);
-    ui->tabWidget->insertTab(0, profileSelector, STR_TR_Profile);
+    ui->tabWidget->insertTab(0, profileSelector,  STR_TR_Profile);
 
     // Profiles haven't been loaded here...
     profileSelector->updateProfileList();
@@ -226,6 +232,8 @@ void MainWindow::SetupGUI()
     ui->action_Sidebar_Toggle->setChecked(b);
     ui->toolBox->setVisible(b);
 
+    ui->actionShowPersonalData->setChecked(AppSetting->showPersonalData());
+
     ui->actionPie_Chart->setChecked(AppSetting->showPieChart());
 
     ui->actionDaily_Calendar->setChecked(AppSetting->calendarVisible());
@@ -431,7 +439,8 @@ bool MainWindow::OpenProfile(QString profileName, bool skippassword)
     qDebug() << "Opening profile" << profileName;
 
     auto pit = Profiles::profiles.find(profileName);
-    if (pit == Profiles::profiles.end()) return false;
+    if (pit == Profiles::profiles.end())
+        return false;
 
     Profile * prof = pit.value();
     if (p_profile) {
@@ -597,11 +606,17 @@ bool MainWindow::OpenProfile(QString profileName, bool skippassword)
     delete progress;
     qDebug() << "Finished opening Profile";
 
+    if (updateChecker != nullptr)
+        updateChecker->showMessage();
+
     return true;
 }
 
 void MainWindow::CloseProfile()
 {
+    if (updateChecker != nullptr)
+        updateChecker->showMessage();
+
     if (daily) {
         daily->Unload();
         daily->clearLastDay(); // otherwise Daily will crash
@@ -796,58 +811,59 @@ void MainWindow::importCPAPBackups()
 QStringList getDriveList()
 {
     QStringList drivelist;
+    bool crostini_detected = false;
 
-#if defined(Q_OS_MAC) || defined(Q_OS_BSD4)
-    struct statfs *mounts;
-    int num_mounts = getmntinfo(&mounts, MNT_WAIT);
-    if (num_mounts >= 0) {
-        for (int i = 0; i < num_mounts; i++) {
-            QString name = mounts[i].f_mntonname;
-
-            // Only interested in drives mounted under /Volumes
-            if (name.toLower().startsWith("/volumes/")) {
-                drivelist.push_back(name);
-//                qDebug() << QString("Disk type '%1' mounted at: %2").arg(mounts[i].f_fstypename).arg(mounts[i].f_mntonname);
-            }
-        }
-    }
-
-#elif defined(Q_OS_UNIX) && !defined(Q_OS_HAIKU)
-    // Unix / Linux (except BSD)
-    FILE *mtab = setmntent("/etc/mtab", "r");
-    struct mntent *m;
-    struct mntent mnt;
-    char strings[4096];
-
-    // NOTE: getmntent_r is a GNU extension, requiring glibc.
-    while ((m = getmntent_r(mtab, &mnt, strings, sizeof(strings)))) {
-
-        struct statfs fs;
-        if ((mnt.mnt_dir != NULL) && (statfs(mnt.mnt_dir, &fs) == 0)) {
-            QString name = mnt.mnt_dir;
-            quint64 size = fs.f_blocks * fs.f_bsize;
-
-            if (size > 0) { // this should theoretically ignore /dev, /proc, /sys etc..
-                drivelist.push_back(name);
-            }
-//            quint64 free = fs.f_bfree * fs.f_bsize;
-//            quint64 avail = fs.f_bavail * fs.f_bsize;
-        }
-    }
-    endmntent(mtab);
-
-#elif defined(Q_OS_WIN) || defined(Q_OS_HAIKU)
-    QFileInfoList list = QDir::drives();
-
-    for (int i = 0; i < list.size(); ++i) {
-        QFileInfo fileInfo = list.at(i);
-        QString name = fileInfo.filePath();
-        if (name.at(0).toUpper() != QChar('C')) { // Ignore the C drive
-            drivelist.push_back(name);
-        }
-    }
-
+#if QT_VERSION >= QT_VERSION_CHECK(5,4,0)
+#if defined(Q_OS_LINUX)
+    #define VFAT "vfat"
+#elif defined(Q_OS_WIN)
+    #define VFAT "FAT32"
+    Q_UNUSED(crostini_detected)
+#elif defined(Q_OS_MAC)
+    #define VFAT "msdos"
+    Q_UNUSED(crostini_detected)
 #endif
+    foreach (const QStorageInfo &storage, QStorageInfo::mountedVolumes()) {
+        if (storage.isValid() && storage.isReady()) {
+#ifdef DEBUG_SDCARD            
+            if (storage.fileSystemType() != "tmpfs") {      // Don't show all the Linux tmpfs mount points!
+                qDebug() << "Device:" << storage.device();
+                qDebug() << "    Path:" << storage.rootPath();
+                qDebug() << "    Name:" << storage.name();     // ...
+                qDebug() << "    FS Type:" << storage.fileSystemType();
+            }
+#endif            
+            if (storage.fileSystemType() == VFAT) {
+                qDebug() << "Adding" << storage.name() << "on" << storage.rootPath() << "to drivelist";
+                drivelist.append(storage.rootPath());
+            } else if (storage.fileSystemType() == "9p") {
+                qDebug() << "Crostini filesystem 9p found";
+                crostini_detected = true;
+            }
+        }
+    }
+#endif
+#if defined(Q_OS_LINUX)
+    if (crostini_detected) {
+	    QString mntName("/mnt/chromeos/removable");
+	    QDir mnt(mntName);
+	    qDebug() << "Checking for" << mntName;
+	    if ( mnt.exists() ) {
+	        qDebug() << "Checking Crostini removable folders";
+	        QFileInfoList mntPts = mnt.entryInfoList();
+	        foreach ( const auto dir, mntPts ) {
+	            qDebug() << "Adding" << dir.filePath() << "to drivelist";
+	            drivelist.append(dir.filePath() );
+	        }
+	    } else {
+            QMessageBox::warning(nullptr, STR_MessageBox_Warning,
+                QObject::tr("Chromebook file system detected, but no removable device found\n") +
+                QObject::tr("You must share your SD card with Linux using the ChromeOS Files program"));
+            drivelist.clear();
+            drivelist.append("CROSTINI");
+        }
+    }
+#endif    
     return drivelist;
 }
 
@@ -860,9 +876,11 @@ void ImportDialogScan::cancelbutton()
 
 QList<ImportPath> MainWindow::detectCPAPCards()
 {
-    const int timeout = 20000;
+    const int timeout = 20000;  // twenty seconds
 
     QList<ImportPath> detectedCards;
+    importScanCancelled = false;
+    QString lastpath = (*p_profile)[STR_PREF_LastCPAPPath].toString();
 
     QList<MachineLoader *>loaders = GetLoaders(MT_CPAP);
     QTime time;
@@ -891,18 +909,22 @@ QList<ImportPath> MainWindow::detectCPAPCards()
     progress.setValue(0);
     progress.setMaximum(timeout);
     progress.setVisible(true);
-    importScanCancelled = false;
+//    importScanCancelled = false;
     popup.show();
     QApplication::processEvents();
-    QString lastpath = (*p_profile)[STR_PREF_LastCPAPPath].toString();
+//    QString lastpath = (*p_profile)[STR_PREF_LastCPAPPath].toString();
 
     do {
         // Rescan in case card inserted
         QStringList AutoScannerPaths = getDriveList();
-        //AutoScannerPaths.push_back(lastpath);
+        if (AutoScannerPaths.contains("CROSTINI"))    // no Crostini removable drives found!
+            break;                                    // break out of the 20 second wait loop
+//      AutoScannerPaths.push_back(lastpath);
+        qDebug() << "Drive list size:" << AutoScannerPaths.size();
 
-        if (!AutoScannerPaths.contains(lastpath)) {
-            AutoScannerPaths.append(lastpath);
+        if ( (lastpath.size()>0) && ( ! AutoScannerPaths.contains(lastpath))) {
+            if (QFile(lastpath).exists())
+                AutoScannerPaths.insert(0, lastpath);
         }
 
         Q_FOREACH(const QString &path, AutoScannerPaths) {
@@ -918,10 +940,12 @@ QList<ImportPath> MainWindow::detectCPAPCards()
         }
         int el=time.elapsed();
         progress.setValue(el);
-        if (el > timeout) break;
-        if (!popup.isVisible()) break;
+        if (el > timeout)
+            break;
+        if ( ! popup.isVisible())
+            break;
         // needs a slight delay here
-        for (int i=0; i<5; ++i) {
+        for (int i=0; i<20; ++i) {
             QThread::msleep(50);
             QApplication::processEvents();
         }
@@ -1151,101 +1175,6 @@ void MainWindow::setStatsHTML(QString html)
 }
 
 
-/***
-QString MainWindow::getWelcomeHTML()
-{
-    // This is messy, but allows it to be translated easier
-    return "<html>\n<head>"
-           " <style type='text/css'>"
-           "  <!--h1,p,a,td,body { font-family: 'FreeSans', 'Sans Serif' } --/>"
-           "  p,a,td,body { font-size: 14px }"
-           "  a:link,a:visited { color: \"#000020\"; text-decoration: none; font-weight: bold;}"
-           "  a:hover { background-color: inherit; color: red; text-decoration:none; font-weight: bold; }"
-           " </style>\n"
-           "</head>"
-           "<body leftmargin=0 topmargin=0 rightmargin=0>"
-           "<table width=\"100%\" cellspacing=0 cellpadding=4 border=0 >"
-           "<tr><td bgcolor=\"#d0d0d0\" colspan=2 cellpadding=0 valign=center align=center><font color=\"black\" size=+1><b>"
-           + tr("Welcome to OSCAR") + "</b></font></td></tr>"
-           "<tr>"
-           "<td valign=\"top\" leftmargin=0 cellpadding=6>"
-           "<h3>" + tr("About OSCAR") + "</h3>"
-           "<p>" + tr("This software has been created to assist you in reviewing the data produced by CPAP Machines, used in the treatment of various Sleep Disorders.")
-           + "</p>"
-           "<p>" + tr("OSCAR has been designed by a software developer with personal experience with a sleep disorder, and shaped by the feedback of many other willing testers dealing with similar conditions.")
-           + "</p>"
-           "<p><i><b>" + tr("This is a beta release, some features may not yet behave as expected.") +
-           "</b></i><br/>" + tr("Please report any bugs you find to the OSCAR developer's group.") + "</p>"
-
-           "<h3>" + tr("Currenly supported machines:") + "</h3>"
-           "<b>" + tr("CPAP") + "</b>"
-           "<li>" + tr("Philips Respironics System One (CPAP Pro, Auto, BiPAP & ASV models)") + "</li>"
-           "<li>" + tr("ResMed S9 models (CPAP, Auto, VPAP)") + "</li>"
-           "<li>" + tr("DeVilbiss Intellipap (Auto)") + "</li>"
-           "<li>" + tr("Fisher & Paykel ICON (CPAP, Auto)") + "</li>"
-           "<b>" + tr("Oximetry") + "</b>"
-           "<li>" + tr("Contec CMS50D+, CMS50E and CMS50F (not 50FW) Oximeters") + "</li>"
-           "<li>" + tr("ResMed S9 Oximeter Attachment") + "</li>"
-           "<p><h3>" + tr("Online Help Resources") + "</h3></p>"
-           "<p><b>" + tr("Note:") + "</b>" +
-           tr("I don't recommend using this built in web browser to do any major surfing in, it will work, but it's mainly meant as a help browser.")
-           +
-           tr("(It doesn't support SSL encryption, so it's not a good idea to type your passwords or personal details anywhere.)")
-           + "</p>" +
-
-//         tr("OSCAR's Online <a href=\"http://sleepyhead.sourceforge.net/wiki/index.php?title=OSCAR_Users_Guide\">Users Guide</a><br/>")
-//         +
-//         tr("<a href=\"http://sleepyhead.sourceforge.net/wiki/index.php?title=Frequently_Asked_Questions\">Frequently Asked Questions</a><br/>")
-//         +
-//         tr("<a href=\"http://sleepyhead.sourceforge.net/wiki/index.php?title=Glossary\">Glossary of Sleep Disorder Terms</a><br/>")
-//         +
-//         tr("<a href=\"http://sleepyhead.sourceforge.net/wiki/index.php?title=Main_Page\">OSCAR Wiki</a><br/>")
-//         +
-//         tr("OSCAR's <a href='http://www.sourceforge.net/projects/sleepyhead'>Project Website</a> on SourceForge<br/>")
-//         +
-           "<p><h3>" + tr("Further Information") + "</h3></p>"
-           "<p>" +
-           tr("The release notes for this version can be found in the About OSCAR menu item.") +
-           "<br/>" +
-           tr("Plus a few <a href='qrc:/docs/usage.html'>usage notes</a>, and some important information for Mac users.")
-           + "<br/>" +
-           "<p>" + tr("About <a href='http://en.wikipedia.org/wiki/Sleep_apnea'>Sleep Apnea</a> on Wikipedia")
-           + "</p>"
-
-           "<p>" + tr("Friendly forums to talk and learn about Sleep Apnea:") + "<br/>" +
-           tr("<a href='http://www.cpaptalk.com'>CPAPTalk Forum</a>,") +
-           tr("<a href='http://www.apneaboard.com/forums/'>Apnea Board</a>") + "</p>"
-           "</td>"
-           "<td><image src='qrc:/icons/logo-lg.png' width=220 height=220><br/>"
-           "</td>"
-           "</tr>"
-           "<tr>"
-           "<td colspan=2>"
-           "<hr/>"
-           "<p><b>" + tr("Copyright:") + "</b> " + "&copy;2011-2018" +
-           " <a href=\"http://jedimark64.blogspot.com\">Mark Watkins</a> (jedimark) and portions &copy;2019 Nightowl Software</p>"
-           "<p><b>" + tr("License:") + "</b> " +
-           tr("This software is released freely under the <a href=\"qrc:/COPYING\">GNU Public License version 3</a>.") +
-           "</p>"
-           "<hr/>"
-           "<p><b>" + tr("DISCLAIMER:") + "</b></p>"
-           "<b><p>" +
-           tr("This is <font color='red'><u>NOT</u></font> medical software. This application is merely a data viewer, and no guarantee is made regarding accuracy or correctness of any calculations or data displayed.")
-           + "</p>"
-           "<p>" + tr("The authors will NOT be held liable by anyone who harms themselves or others by use or misuse of this software.")
-           + "</p>"
-           "<p>" + tr("Your doctor should always be your first and best source of guidance regarding the important matter of managing your health.")
-           + "</p>"
-           "<p>" + tr("*** <u>Use at your own risk</u> ***") + "</p></b>"
-           "<hr/>"
-           "</td></tr>"
-           "</table>"
-           "</body>"
-           "</html>"
-
-           ;
-}
-***/
 void MainWindow::updateFavourites()
 {
     QDate date = p_profile->LastDay(MT_JOURNAL);
@@ -1441,24 +1370,23 @@ void MainWindow::on_oximetryButton_clicked()
     }
 }
 
-void MainWindow::CheckForUpdates()
+// Called for automatic check for updates
+void MainWindow::CheckForUpdates(bool showWhenCurrent)
 {
-    qDebug() << "procedure <CheckForUpdates> called";
-#ifndef NO_UPDATER
-    on_actionCheck_for_Updates_triggered();
+    updateChecker = new CheckUpdates(this);
+#ifdef NO_CHECKUPDATES
+    if (showWhenCurrent)
+        QMessageBox::information(nullptr, STR_MessageBox_Information, tr("Check for updates not implemented"));
 #else
-    QMessageBox::information(nullptr, STR_MessageBox_Information, tr("Updates are not yet implemented"));
+    updateChecker->checkForUpdates(showWhenCurrent);
 #endif
 }
 
-#ifndef NO_UPDATER
-void MainWindow::on_actionCheck_for_Updates_triggered()
+// Called for manual check for updates
+void MainWindow::on_action_Check_for_Updates_triggered()
 {
-    qDebug() << "procedure <on_actionCheck_for_Updates_triggered> called";
-    UpdaterWindow *w = new UpdaterWindow(this);
-    w->checkForUpdates();
+    CheckForUpdates(true);
 }
-#endif
 
 bool toolbox_visible = false;
 void MainWindow::on_action_Screenshot_triggered()
@@ -1827,7 +1755,7 @@ void MainWindow::RestartApplication(bool force_login, QString cmdline)
     if (QProcess::startDetached("/usr/bin/open", args)) {
         QApplication::instance()->exit();
     } else { 
-        QMessageBox::warning(nullptr, tr("Gah!"), 
+        QMessageBox::warning(nullptr, STR_MessageBox_Error,
             tr("If you can read this, the restart command didn't work. You will have to do it yourself manually."), QMessageBox::Ok);
     }
 
@@ -1854,7 +1782,7 @@ void MainWindow::RestartApplication(bool force_login, QString cmdline)
 
 //        ::exit(0);
     } else { 
-        QMessageBox::warning(nullptr, tr("Gah!"), 
+        QMessageBox::warning(nullptr,  STR_MessageBox_Error,
             tr("If you can read this, the restart command didn't work. You will have to do it yourself manually."), QMessageBox::Ok);
     }
 
@@ -1877,59 +1805,13 @@ void MainWindow::on_actionPurge_Current_Day_triggered()
         QList<Session *>::iterator s;
 
         QList<Session *> list;
-        QList<SessionID> sidlist;
         for (s = day->begin(); s != day->end(); ++s) {
-            list.push_back(*s);
+            list.append(*s);
             qDebug() << "Purging session ID:" << (*s)->session() << "["+QDateTime::fromTime_t((*s)->session()).toString()+"]";
             qDebug() << "First Time:" << QDateTime::fromMSecsSinceEpoch((*s)->realFirst()).toString();
             qDebug() << "Last Time:" << QDateTime::fromMSecsSinceEpoch((*s)->realLast()).toString();
-            sidlist.push_back((*s)->session());
         }
 
-        QHash<QString, SessionID> skipfiles;
-        // Read the already imported file list
-
-        QFile impfile(cpap->getDataPath()+"/imported_files.csv");
-        if (impfile.exists()) {
-            qDebug() << "Obsolet file exists" << impfile.fileName();
-            if (impfile.open(QFile::ReadOnly)) {
-                QTextStream impstream(&impfile);
-                QString serial;
-                impstream >> serial;
-                if (cpap->serial() == serial) {
-                    QString line, file, str;
-                    SessionID sid;
-                    bool ok;
-                    do {
-                        line = impstream.readLine();
-                        file = line.section(',',0,0);
-                        str = line.section(',',1);
-                        sid = str.toInt(&ok);
-                        if (!sidlist.contains(sid)) {
-                            skipfiles[file] = sid;
-                        }
-                    } while (!impstream.atEnd());
-                }
-            }
-            impfile.close();
-            // Delete the file
-            impfile.remove();
-
-            // Rewrite the file without the sessions being removed.
-            if (impfile.open(QFile::WriteOnly)) {
-                QTextStream out(&impfile);
-                out << cpap->serial();
-                QHash<QString, SessionID>::iterator skit;
-                QHash<QString, SessionID>::iterator skit_end = skipfiles.end();
-                for (skit = skipfiles.begin(); skit != skit_end; ++skit) {
-                    QString a = QString("%1,%2\n").arg(skit.key()).arg(skit.value());;
-                    out << a;
-                }
-                out.flush();
-            }
-            impfile.close();
-        }                   // end of obsolte file code
-
         QFile rxcache(p_profile->Get("{" + STR_GEN_DataFolder + "}/RXChanges.cache" ));
         rxcache.remove();
 
@@ -1940,10 +1822,14 @@ void MainWindow::on_actionPurge_Current_Day_triggered()
 
         for (int i = 0; i < list.size(); i++) {
             Session *sess = list.at(i);
-            sess->Destroy();
+            sess->Destroy();    // remove the summary and event files
             delete sess;
         }
 
+        // save purge date where later import should start
+        QDate pd = cpap->purgeDate();
+        if (pd.isNull() || day->date() < pd)
+            cpap->setPurgeDate(day->date());
     }
     day = p_profile->GetDay(date, MT_CPAP);
     Q_UNUSED(day);
@@ -2096,7 +1982,7 @@ void MainWindow::purgeMachine(Machine * mach)
         delete mach;
         // remove the directory unless it's got unexpected crap in it..
         bool deleted = false;
-        if (!dir.rmdir(path)) {
+        if ( ! dir.rmdir(path)) {
 #ifdef Q_OS_WIN
             wchar_t* directoryPtr = (wchar_t*)path.utf16();
             SetFileAttributes(directoryPtr, GetFileAttributes(directoryPtr) & ~FILE_ATTRIBUTE_READONLY);
@@ -2112,13 +1998,13 @@ void MainWindow::purgeMachine(Machine * mach)
                deleted = true;
             }
 #else
-            qDebug() << "Couldn't remove directory" << path;
+            qWarning() << "Couldn't remove directory" << path;
 #endif
         } else {
             deleted = true;
         }
-        if (!deleted) {
-            qDebug() << "Leaving backup folder intact";
+        if ( ! deleted) {
+            qWarning() << "Leaving backup folder intact";
         }
 
         PopulatePurgeMenu();
@@ -2710,6 +2596,13 @@ void MainWindow::on_actionDaily_Calendar_toggled(bool visible)
     if (daily) daily->setCalendarVisible(visible);
 }
 
+void MainWindow::on_actionShowPersonalData_toggled(bool visible)
+{
+    AppSetting->setShowPersonalData(visible);
+    if (!setupRunning)
+        GenerateStatistics();
+}
+
 #include "SleepLib/journal.h"
 
 void MainWindow::on_actionExport_Journal_triggered()
@@ -2770,7 +2663,7 @@ void MainWindow::on_actionCreate_Card_zip_triggered()
                 infostr = datacard.loader->loaderName();
             }
             prefix = infostr;
-            folder += QDir::separator() + infostr + ".zip";
+            folder += "/" + infostr + ".zip";
 
             filename = QFileDialog::getSaveFileName(this, tr("Choose where to save zip"), folder, tr("ZIP files (*.zip)"));
 
@@ -2815,6 +2708,56 @@ void MainWindow::on_actionCreate_Card_zip_triggered()
     }
 }
 
+
+void MainWindow::on_actionCreate_Log_zip_triggered()
+{
+    QString folder;
+
+    // Note: macOS ignores this and points to OSCAR's most recently used directory for saving.
+    folder = QStandardPaths::writableLocation(QStandardPaths::DocumentsLocation);
+    folder += "/OSCAR-logs.zip";
+    QString filename = QFileDialog::getSaveFileName(this, tr("Choose where to save zip"), folder, tr("ZIP files (*.zip)"));
+    if (filename.isEmpty()) {
+        return;  // aborted
+    }
+    if (!filename.toLower().endsWith(".zip")) {
+        filename += ".zip";
+    }
+    
+    qDebug() << "Create zip of OSCAR diagnostic logs:" << filename;
+
+    ZipFile z;
+    bool ok = z.Open(filename);
+    if (ok) {
+        ProgressDialog * prog = new ProgressDialog(this);
+        prog->setMessage(tr("Creating zip..."));
+
+        // Build the list of files.
+        FileQueue files;
+        files.AddDirectory(GetLogDir(), "logs");
+
+        // Defer the current debug log to the end.
+        QString debugLog = logger->logFileName();
+        QString debugLogZipName;
+        int exists = files.Remove(debugLog, &debugLogZipName);
+        if (exists) {
+            files.AddFile(debugLog, debugLogZipName);
+        }
+
+        // Create the zip.
+        ok = z.AddFiles(files, prog);
+        z.Close();
+    } else {
+        qWarning() << "Unable to open" << filename;
+    }
+    if (!ok) {
+        QMessageBox::warning(nullptr, STR_MessageBox_Error,
+            QObject::tr("Unable to create zip!"),
+            QMessageBox::Ok);
+    }
+}
+
+
 void MainWindow::on_actionCreate_OSCAR_Data_zip_triggered()
 {
     QString folder;
@@ -2822,7 +2765,7 @@ void MainWindow::on_actionCreate_OSCAR_Data_zip_triggered()
     // Note: macOS ignores this and points to OSCAR's most recently used directory for saving.
     folder = QStandardPaths::writableLocation(QStandardPaths::DocumentsLocation);
 
-    folder += QDir::separator() + STR_AppData + ".zip";
+    folder += "/" + STR_AppData + ".zip";
 
     QString filename = QFileDialog::getSaveFileName(this, tr("Choose where to save zip"), folder, tr("ZIP files (*.zip)"));
 
@@ -2837,7 +2780,6 @@ void MainWindow::on_actionCreate_OSCAR_Data_zip_triggered()
     qDebug() << "Create zip of OSCAR data folder:" << filename;
 
     QDir oscarData(GetAppData());
-    QFile debugLog(oscarData.canonicalPath() + QDir::separator() + "debuglog.txt");
 
     ZipFile z;
     bool ok = z.Open(filename);
@@ -2847,29 +2789,22 @@ void MainWindow::on_actionCreate_OSCAR_Data_zip_triggered()
         prog->setWindowModality(Qt::ApplicationModal);
         prog->open();
 
-        // Build the list of files and exclude any existing debug log.
+        // Build the list of files.
         FileQueue files;
         files.AddDirectory(oscarData.canonicalPath(), oscarData.dirName());
-        files.Remove(debugLog.fileName());
+
+        // Defer the current debug log to the end.
+        QString debugLog = logger->logFileName();
+        QString debugLogZipName;
+        int exists = files.Remove(debugLog, &debugLogZipName);
+        if (exists) {
+            files.AddFile(debugLog, debugLogZipName);
+        }
 
         prog->setMessage(tr("Creating zip..."));
 
         // Create the zip.
         ok = z.AddFiles(files, prog);
-        if (ok && z.aborted() == false) {
-            // Update the debug log and add it last.
-            ok = debugLog.open(QIODevice::WriteOnly);
-            if (ok) {
-                debugLog.write(ui->logText->toPlainText().toLocal8Bit().data());
-                debugLog.close();
-                QString debugLogName = oscarData.dirName() + "/" + QFileInfo(debugLog).fileName();
-                ok = z.AddFile(debugLog.fileName(), debugLogName);
-                if (!ok) {
-                    qWarning() << "Unable to add debug log to zip!";
-                }
-            }
-        }
-
         z.Close();
     } else {
         qWarning() << "Unable to open" << filename;
