@@ -22,6 +22,7 @@
 #include <cmath>
 
 #include "preferencesdialog.h"
+#include "version.h"
 
 #include <Graphs/gGraphView.h>
 #include <mainwindow.h>
@@ -216,12 +217,30 @@ PreferencesDialog::PreferencesDialog(QWidget *parent, Profile *_profile) :
     ui->graphTooltips->setChecked(AppSetting->graphTooltips());
     ui->allowYAxisScaling->setChecked(AppSetting->allowYAxisScaling());
     ui->includeSerial->setChecked(AppSetting->includeSerial());
+    ui->monochromePrinting->setChecked(AppSetting->monochromePrinting());
 
     ui->autoLaunchImporter->setChecked(AppSetting->autoLaunchImport());
-#ifndef NO_UPDATER
+#ifndef NO_CHECKUPDATES
+    ui->updateCheckEvery->setValue(AppSetting->updateCheckFrequency());
     ui->allowEarlyUpdates->setChecked(AppSetting->allowEarlyUpdates());
+    ui->test_invite->setVisible(false);
+    if (!getVersion().IsReleaseVersion()) {
+        // Test version
+        ui->automaticallyCheckUpdates->setVisible(false);
+        ui->allowEarlyUpdates->setVisible(false);
+        ui->updateCheckEvery->setMaximum(7);
+    }
+    else {
+        // Release version
+        ui->updateCheckEvery->setMaximum(90);
+        ui->always_look_for_updates->setVisible(false);
+        if (!AppSetting->allowEarlyUpdates()) {
+            ui->test_invite->setVisible(true);
+            ui->allowEarlyUpdates->setVisible(false);
+        }
+    }
 #else
-    ui->automaticallyCheckUpdates->setVisible(false);
+    ui->automaticallyCheckUpdates_GroupBox->setVisible(false);
 #endif
 
     int s = profile->cpap->clockDrift();
@@ -266,7 +285,7 @@ PreferencesDialog::PreferencesDialog(QWidget *parent, Profile *_profile) :
 
     ui->graphHeight->setValue(AppSetting->graphHeight());
 
-#ifndef NO_UPDATER
+#ifndef NO_CHECKUPDATES
     ui->automaticallyCheckUpdates->setChecked(AppSetting->updatesAutoCheck());
     ui->updateCheckEvery->setValue(AppSetting->updateCheckFrequency());
     if (AppSetting->updatesLastChecked().isValid()) {
@@ -810,6 +829,7 @@ bool PreferencesDialog::Save()
 
     AppSetting->setAllowYAxisScaling(ui->allowYAxisScaling->isChecked());
     AppSetting->setIncludeSerial(ui->includeSerial->isChecked());
+    AppSetting->setMonochromePrinting(ui->monochromePrinting->isChecked());
     AppSetting->setGraphTooltips(ui->graphTooltips->isChecked());
 
     AppSetting->setAntiAliasing(ui->useAntiAliasing->isChecked());
@@ -901,7 +921,7 @@ bool PreferencesDialog::Save()
 
     AppSetting->setAutoLaunchImport(ui->autoLaunchImporter->isChecked());
 
-#ifndef NO_UPDATER
+#ifndef NO_CHECKUPDATES
     AppSetting->setUpdatesAutoCheck(ui->automaticallyCheckUpdates->isChecked());
     AppSetting->setUpdateCheckFrequency(ui->updateCheckEvery->value());
     AppSetting->setAllowEarlyUpdates(ui->allowEarlyUpdates->isChecked());
@@ -1058,18 +1078,13 @@ void PreferencesDialog::on_IgnoreSlider_valueChanged(int position)
     } else { ui->IgnoreLCD->display(STR_TR_Off); }
 }
 
-#ifndef NO_UPDATER
+#ifndef NO_CHECKUPDATES
 #include "mainwindow.h"
 extern MainWindow *mainwin;
 void PreferencesDialog::RefreshLastChecked()
 {
     ui->updateLastChecked->setText(AppSetting->updatesLastChecked().toString(Qt::SystemLocaleLongDate));
 }
-
-void PreferencesDialog::on_checkForUpdatesButton_clicked()
-{
-    mainwin->CheckForUpdates();
-}
 #endif
 
 MySortFilterProxyModel::MySortFilterProxyModel(QObject *parent)
